From: Peter Rajnoha <prajnoha@redhat.com>

Add devname:mapper/control and MAPPER_CTRL_MINOR module alias
to support dm-mod module autoloading.

Signed-off-by: Kay Sievers <kay.sievers@vrfy.org>
Signed-off-by: Peter Rajnoha <prajnoha@redhat.com>
Signed-off-by: Alasdair G Kergon <agk@redhat.com>

---
 Documentation/devices.txt  |    1 +
 drivers/md/dm-ioctl.c      |    7 +++++--
 include/linux/dm-ioctl.h   |    1 +
 include/linux/miscdevice.h |    1 +
 4 files changed, 8 insertions(+), 2 deletions(-)

Index: linux-2.6.35/Documentation/devices.txt
===================================================================
--- linux-2.6.35.orig/Documentation/devices.txt
+++ linux-2.6.35/Documentation/devices.txt
@@ -445,6 +445,7 @@ Your cooperation is appreciated.
 		233 = /dev/kmview	View-OS A process with a view
 		234 = /dev/btrfs-control	Btrfs control device
 		235 = /dev/autofs	Autofs control device
+		236 = /dev/mapper/control	Device-Mapper control device
 		240-254			Reserved for local use
 		255			Reserved for MISC_DYNAMIC_MINOR
 
Index: linux-2.6.35/drivers/md/dm-ioctl.c
===================================================================
--- linux-2.6.35.orig/drivers/md/dm-ioctl.c
+++ linux-2.6.35/drivers/md/dm-ioctl.c
@@ -1599,12 +1599,15 @@ static const struct file_operations _ctl
 };
 
 static struct miscdevice _dm_misc = {
-	.minor 		= MISC_DYNAMIC_MINOR,
+	.minor		= MAPPER_CTRL_MINOR,
 	.name  		= DM_NAME,
-	.nodename	= "mapper/control",
+	.nodename	= DM_DIR "/" DM_CONTROL_NODE,
 	.fops  		= &_ctl_fops
 };
 
+MODULE_ALIAS_MISCDEV(MAPPER_CTRL_MINOR);
+MODULE_ALIAS("devname:" DM_DIR "/" DM_CONTROL_NODE);
+
 /*
  * Create misc character device and link to DM_DIR/control.
  */
Index: linux-2.6.35/include/linux/dm-ioctl.h
===================================================================
--- linux-2.6.35.orig/include/linux/dm-ioctl.h
+++ linux-2.6.35/include/linux/dm-ioctl.h
@@ -11,6 +11,7 @@
 #include <linux/types.h>
 
 #define DM_DIR "mapper"		/* Slashes not supported */
+#define DM_CONTROL_NODE "control"
 #define DM_MAX_TYPE_NAME 16
 #define DM_NAME_LEN 128
 #define DM_UUID_LEN 129
Index: linux-2.6.35/include/linux/miscdevice.h
===================================================================
--- linux-2.6.35.orig/include/linux/miscdevice.h
+++ linux-2.6.35/include/linux/miscdevice.h
@@ -38,6 +38,7 @@
 #define KVM_MINOR		232
 #define BTRFS_MINOR		234
 #define AUTOFS_MINOR		235
+#define MAPPER_CTRL_MINOR	236
 #define MISC_DYNAMIC_MINOR	255
 
 struct device;
